RecursiveError

Enum RecursiveError 

pub enum RecursiveError {
    Root {
        context: &'static str,
        source: Box<Error>,
    },
    TransactionContext {
        context: &'static str,
        source: Box<Error>,
    },
    E2e {
        context: &'static str,
        source: Box<E2eIdentityError>,
    },
    MlsClient {
        context: &'static str,
        source: Box<Error>,
    },
    MlsConversation {
        context: &'static str,
        source: Box<Error>,
    },
    MlsCredential {
        context: &'static str,
        source: Box<Error>,
    },
}
These errors wrap each of the module-specific errors in CoreCrypto.

The goal here is to reduce the need to redeclare each of these error types as an individual variant of a module-specific error type.

Variants



Root

Fields

context: &'static str
source: Box<Error>


TransactionContext

Fields

context: &'static str
source: Box<Error>


E2e

Fields

context: &'static str


MlsClient

Fields

context: &'static str
source: Box<Error>


MlsConversation

Fields

context: &'static str
source: Box<Error>


MlsCredential

Fields

context: &'static str
source: Box<Error>

Implementations

Source

impl RecursiveError

pub fn root<E: Into<Error>>(context: &'static str) -> impl FnOnce(E) -> Self

Wrap an error convertible into crate::Error, given the current context.

Prefer Self::context unless you are relying on the Into conversion.

pub fn transaction<E: Into<Error>>( context: &'static str, ) -> impl FnOnce(E) -> Self

Wrap an error convertible into crate::transaction_context::Error, given the current context.

Prefer Self::context unless you are relying on the Into conversion.

pub fn e2e_identity<E: Into<E2eIdentityError>>( context: &'static str, ) -> impl FnOnce(E) -> Self

Wrap an error convertible into wire_e2e_identity::E2eIdentityError, given the current context.

Prefer Self::context unless you are relying on the Into conversion.

pub fn mls_client<E: Into<Error>>( context: &'static str, ) -> impl FnOnce(E) -> Self

Wrap an error convertible into crate::mls::session::Error, given the current context.

Prefer Self::context unless you are relying on the Into conversion.

pub fn mls_conversation<E: Into<Error>>( context: &'static str, ) -> impl FnOnce(E) -> Self

Wrap an error convertible into crate::mls::conversation::Error, given the current context.

Prefer Self::context unless you are relying on the Into conversion.

pub fn mls_credential<E: Into<Error>>( context: &'static str, ) -> impl FnOnce(E) -> Self

Wrap an error convertible into crate::mls::credential::Error, given the current context.

Prefer Self::context unless you are relying on the Into conversion.

Source

impl RecursiveError

pub fn context<E: ToRecursiveError>( context: &'static str, ) -> impl FnOnce(E) -> Self

Wrap any error which RecursiveError knows how to wrap, given the current context.

The variant is selected from the error’s type, so this is usually what you want:

self.session().await.map_err(RecursiveError::context("getting mls client"))?

This only accepts the module error types themselves. When you need to convert first, for instance because you are holding a crate::TlsCodecError which several module errors can absorb, reach for the variant-specific constructor such as Self::mls_conversation instead.