pub enum BufferedDecryptedMessage {
Text(Text),
Commit(BufferedCommit),
Proposal(Proposal),
}Expand description
A decrypted message that was buffered due to out-of-order delivery by the delivery service. It represents messages for the new epoch that arrived before the commit that created it.
Variants
Text(Text)
The decrypted message is a text message.
Commit(BufferedCommit)
The decrypted message is a commit.
Proposal(Proposal)
The decrypted message is a proposal.