DecryptedMessage

Enum DecryptedMessage 

pub enum DecryptedMessage {
    ApplicationMessage(DecryptedBytes),
    Commit(Commit),
    Proposal(Proposal),
    Transient(DecryptedBytes),
    TransientTargeted(DecryptedBytes),
    PersistedTargeted(DecryptedBytes),
}
Represents the items a consumer might require after decrypting a message.

Variants



ApplicationMessage(DecryptedBytes)

The decrypted message is an MLS application message.



Commit(Commit)

The decrypted message is a commit.



Proposal(Proposal)

The decrypted message is a proposal.



Transient(DecryptedBytes)

The decrypted message is a transient targeted message.



TransientTargeted(DecryptedBytes)

The decrypted message is a transient targeted message.



PersistedTargeted(DecryptedBytes)

The decrypted message is a persisted targeted message.

Implementations

Source

impl DecryptedMessage

pub fn is_application_message(&self) -> bool

Returns true if this is a DecryptedMessage::ApplicationMessage, otherwise false

pub fn as_application_message_mut(&mut self) -> Option<&mut DecryptedBytes>

Optionally returns mutable references to the inner fields if this is a DecryptedMessage::ApplicationMessage, otherwise None

pub fn as_application_message(&self) -> Option<&DecryptedBytes>

Optionally returns references to the inner fields if this is a DecryptedMessage::ApplicationMessage, otherwise None

pub fn into_application_message(self) -> Result<DecryptedBytes, Self>

Returns the inner fields if this is a DecryptedMessage::ApplicationMessage, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_application_message_unchecked(self) -> DecryptedBytes

Unchecked return of the inner fields of DecryptedMessage::ApplicationMessage.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_application_message_unchecked(&self) -> &DecryptedBytes

Unchecked reference of the inner fields of DecryptedMessage::ApplicationMessage.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_application_message_mut_unchecked( &mut self, ) -> &mut DecryptedBytes

Unchecked mutable reference of the inner fields of DecryptedMessage::ApplicationMessage.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_commit(&self) -> bool

Returns true if this is a DecryptedMessage::Commit, otherwise false

pub fn as_commit_mut(&mut self) -> Option<&mut Commit>

Optionally returns mutable references to the inner fields if this is a DecryptedMessage::Commit, otherwise None

pub fn as_commit(&self) -> Option<&Commit>

Optionally returns references to the inner fields if this is a DecryptedMessage::Commit, otherwise None

pub fn into_commit(self) -> Result<Commit, Self>

Returns the inner fields if this is a DecryptedMessage::Commit, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_commit_unchecked(self) -> Commit

Unchecked return of the inner fields of DecryptedMessage::Commit.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_commit_unchecked(&self) -> &Commit

Unchecked reference of the inner fields of DecryptedMessage::Commit.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_commit_mut_unchecked(&mut self) -> &mut Commit

Unchecked mutable reference of the inner fields of DecryptedMessage::Commit.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_proposal(&self) -> bool

Returns true if this is a DecryptedMessage::Proposal, otherwise false

pub fn as_proposal_mut(&mut self) -> Option<&mut Proposal>

Optionally returns mutable references to the inner fields if this is a DecryptedMessage::Proposal, otherwise None

pub fn as_proposal(&self) -> Option<&Proposal>

Optionally returns references to the inner fields if this is a DecryptedMessage::Proposal, otherwise None

pub fn into_proposal(self) -> Result<Proposal, Self>

Returns the inner fields if this is a DecryptedMessage::Proposal, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_proposal_unchecked(self) -> Proposal

Unchecked return of the inner fields of DecryptedMessage::Proposal.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_proposal_unchecked(&self) -> &Proposal

Unchecked reference of the inner fields of DecryptedMessage::Proposal.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_proposal_mut_unchecked(&mut self) -> &mut Proposal

Unchecked mutable reference of the inner fields of DecryptedMessage::Proposal.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_transient(&self) -> bool

Returns true if this is a DecryptedMessage::Transient, otherwise false

pub fn as_transient_mut(&mut self) -> Option<&mut DecryptedBytes>

Optionally returns mutable references to the inner fields if this is a DecryptedMessage::Transient, otherwise None

pub fn as_transient(&self) -> Option<&DecryptedBytes>

Optionally returns references to the inner fields if this is a DecryptedMessage::Transient, otherwise None

pub fn into_transient(self) -> Result<DecryptedBytes, Self>

Returns the inner fields if this is a DecryptedMessage::Transient, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_transient_unchecked(self) -> DecryptedBytes

Unchecked return of the inner fields of DecryptedMessage::Transient.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_transient_unchecked(&self) -> &DecryptedBytes

Unchecked reference of the inner fields of DecryptedMessage::Transient.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_transient_mut_unchecked(&mut self) -> &mut DecryptedBytes

Unchecked mutable reference of the inner fields of DecryptedMessage::Transient.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_transient_targeted(&self) -> bool

Returns true if this is a DecryptedMessage::TransientTargeted, otherwise false

pub fn as_transient_targeted_mut(&mut self) -> Option<&mut DecryptedBytes>

Optionally returns mutable references to the inner fields if this is a DecryptedMessage::TransientTargeted, otherwise None

pub fn as_transient_targeted(&self) -> Option<&DecryptedBytes>

Optionally returns references to the inner fields if this is a DecryptedMessage::TransientTargeted, otherwise None

pub fn into_transient_targeted(self) -> Result<DecryptedBytes, Self>

Returns the inner fields if this is a DecryptedMessage::TransientTargeted, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_transient_targeted_unchecked(self) -> DecryptedBytes

Unchecked return of the inner fields of DecryptedMessage::TransientTargeted.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_transient_targeted_unchecked(&self) -> &DecryptedBytes

Unchecked reference of the inner fields of DecryptedMessage::TransientTargeted.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_transient_targeted_mut_unchecked( &mut self, ) -> &mut DecryptedBytes

Unchecked mutable reference of the inner fields of DecryptedMessage::TransientTargeted.

Safety

Results in undefined behavior when it is the incorrect variant.

pub fn is_persisted_targeted(&self) -> bool

Returns true if this is a DecryptedMessage::PersistedTargeted, otherwise false

pub fn as_persisted_targeted_mut(&mut self) -> Option<&mut DecryptedBytes>

Optionally returns mutable references to the inner fields if this is a DecryptedMessage::PersistedTargeted, otherwise None

pub fn as_persisted_targeted(&self) -> Option<&DecryptedBytes>

Optionally returns references to the inner fields if this is a DecryptedMessage::PersistedTargeted, otherwise None

pub fn into_persisted_targeted(self) -> Result<DecryptedBytes, Self>

Returns the inner fields if this is a DecryptedMessage::PersistedTargeted, otherwise returns back the enum in the Err case of the result

pub unsafe fn into_persisted_targeted_unchecked(self) -> DecryptedBytes

Unchecked return of the inner fields of DecryptedMessage::PersistedTargeted.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_persisted_targeted_unchecked(&self) -> &DecryptedBytes

Unchecked reference of the inner fields of DecryptedMessage::PersistedTargeted.

Safety

Results in undefined behavior when it is the incorrect variant.

pub unsafe fn as_persisted_targeted_mut_unchecked( &mut self, ) -> &mut DecryptedBytes

Unchecked mutable reference of the inner fields of DecryptedMessage::PersistedTargeted.

Safety

Results in undefined behavior when it is the incorrect variant.

Source

impl DecryptedMessage

pub fn identity(&self) -> &WireIdentity

Identity claims present in the sender credential