#[repr(u8)]pub enum TargetedMessagePolicy {
Transient = 0,
Persisted = 1,
}Expand description
The policy to encrypt the targeted message with.
Variants
Transient = 0
Won’t be persisted and will only visible to currently online members who immediately process it.
Persisted = 1
May be persisted and buffered, will also be delivered and processed by currently offline members.