pub struct BufferedCommit {
pub is_active: bool,
pub identity: WireIdentity,
}Expand description
The data relevant after a buffered Commit was processed.
Fields
is_active: boolIs the conversation still active after receiving this commit, i.e., has the user been removed from the group
identity: WireIdentityIdentity claims present in the sender credential