pub struct Commit {
pub is_active: bool,
pub buffered_messages: Option<Vec<BufferedDecryptedMessage>>,
pub identity: WireIdentity,
}Expand description
The data relevant after a Commit was processed.
Fields
is_active: boolIs the conversation still active after receiving this commit, i.e., has the user been removed from the group
buffered_messages: Option<Vec<BufferedDecryptedMessage>>Contains buffered messages for next epoch which were received before the commit creating the epoch because the DS did not fan them out in order.
identity: WireIdentityIdentity claims present in the sender credential