pub struct CommitBundle {
pub welcome: Option<MlsMessageOut>,
pub commit: MlsMessageOut,
pub group_info: GroupInfoBundle,
pub encrypted_message: Option<Vec<u8>>,
}Expand description
Returned when a commit is created
Fields
welcome: Option<MlsMessageOut>A welcome message if there are pending Add proposals
commit: MlsMessageOutThe commit message
group_info: GroupInfoBundleGroupInfo if the commit is merged
encrypted_message: Option<Vec<u8>>An encrypted message to fan out to all other conversation members in the new epoch
Implementations
Sourceimpl CommitBundle
impl CommitBundle
Sourcepub fn to_bytes_triple(
self,
) -> Result<(Option<WelcomeMessage>, Vec<u8>, GroupInfoBundle)>
pub fn to_bytes_triple( self, ) -> Result<(Option<WelcomeMessage>, Vec<u8>, GroupInfoBundle)>
Unpacks this struct and serializes the commit
0 -> welcome 1 -> message 2 -> public group state