Conversation

Struct Conversation 

pub struct Conversation { /* private fields */ }
A Conversation exposes the read-only interface of an MLS conversation.

Implementations

Source

impl Conversation

pub async fn get_client_ids(&self) -> Vec<ClientId>

Exports the clients from a conversation

Arguments
  • conversation_id - the group/conversation id
pub async fn members_in_next_epoch(&self) -> Vec<ClientId>

Get actual group members and subtract pending remove proposals

Source

impl Conversation

pub async fn compute_next_commit_delay(&self) -> Option<u64>

Helps consumer by providing a deterministic delay in seconds for him to commit its pending proposal. It depends on the index of the client in the ratchet tree

  • self_index - ratchet tree index of self client
  • epoch - current group epoch
  • nb_members - number of clients in the group
Source

impl Conversation

pub async fn members(&self) -> HashMap<Vec<u8>, MlsCredential>

Returns all members credentials from the group/conversation

pub async fn members_with_key(&self) -> HashMap<Vec<u8>, CredentialWithKey>

Returns all members credentials with their signature public key from the group/conversation

Source

impl Conversation

pub async fn e2ei_conversation_state(&self) -> Result<E2eiConversationState>

Indicates when to mark a conversation as not verified i.e. when not all its members have a X509 Credential generated by Wire’s end-to-end identity enrollment

pub async fn get_device_identities( &self, device_ids: &[impl Borrow<ClientIdRef> + Sync], ) -> Result<Vec<WireIdentity>>

From a given conversation, get the identity of the members supplied. Identity is only present for members with a Certificate Credential (after turning on end-to-end identity). If no member has a x509 certificate, it will return an empty Vec

pub async fn get_user_identities( &self, user_ids: &[String], ) -> Result<HashMap<String, Vec<WireIdentity>>>

From a given conversation, get the identity of the users (device holders) supplied. Identity is only present for devices with a Certificate Credential (after turning on end-to-end identity). If no member has a x509 certificate, it will return an empty Vec.

Returns a Map with all the identities for a given users. Consumers are then recommended to reduce those identities to determine the actual status of a user.

Source

impl Conversation

pub async fn generate_history_secret(&self) -> Result<HistorySecret>

Generate a new crate::HistorySecret.

This is useful when it’s this client’s turn to generate a new history client.

The generated secret is cryptographically unrelated to the current CoreCrypto client.

pub async fn is_history_sharing_enabled(&self) -> bool

Check if history sharing is enabled, i.e., if any of the conversation members have a ClientId starting with crate::HISTORY_CLIENT_ID_PREFIX.

Source

impl Conversation

pub const fn new( id: ConversationId, group: RwLock<MlsGroup>, configuration: ConversationConfiguration, session: Session, ) -> Conversation

Source

impl Conversation

pub fn id(&self) -> &ConversationIdRef

Returns the conversation’s ID

pub async fn group(&self) -> RwLockReadGuard<'_, MlsGroup>

Returns an immutable guard over the underlying MLS group

pub fn configuration(&self) -> &ConversationConfiguration

Returns the conversation’s configuration

pub async fn epoch(&self) -> u64

Returns current epoch of the MLS group

pub fn cipher_suite(&self) -> CipherSuite

Returns this conversation’s cipher suite

pub async fn credential_ref(&self) -> Result<CredentialRef>

Returns a reference to the credential used in this conversation

pub async fn export_secret_key(&self, key_length: usize) -> Result<SecretKey>

Derives a new key from the one in the group, to be used elsewhere.

Arguments
  • key_length - the length of the key to be derived. If the value is higher than the bounds of u16 or the context hash * 255, an error will be returned
Errors

OpenMls secret generation error

pub async fn get_external_sender(&self) -> Result<ExternalSenderKey>

Returns the raw public key of the first external sender present in this group.

This should be used to initialize a subconversation