pub struct CustomConfiguration {
pub key_rotation_span: Option<Duration>,
pub wire_policy: WirePolicy,
pub out_of_order_tolerance: u32,
pub maximum_forward_distance: u32,
}Expand description
The configuration parameters for a group/conversation which are not handled natively by openmls
Fields
key_rotation_span: Option<Duration>Duration in seconds after which we will automatically force a self_update commit
wire_policy: WirePolicyDefines if handshake messages are encrypted or not
out_of_order_tolerance: u32Window for which decryption secrets are kept within an epoch. Use this with caution since this affects forward secrecy within an epoch. Use this when the Delivery Service cannot guarantee application messages order.
maximum_forward_distance: u32How many application messages can be skipped. Use this when the Delivery Service can drop application messages