pub struct ExternalSender(/* private fields */);Expand description
A RFC 9420 External Sender
This can be used to initialize a subconversation.
Implementations
Sourceimpl ExternalSender
impl ExternalSender
Sourcepub fn serialize(&self) -> Vec<u8> ⓘ
pub fn serialize(&self) -> Vec<u8> ⓘ
Serialize this external sender into a byte vector.
This produces the public key and matches Self::parse_public_key.
Sourcepub fn parse_jwk(jwk: &[u8]) -> Result<ExternalSender>
pub fn parse_jwk(jwk: &[u8]) -> Result<ExternalSender>
Parse an external sender given a JWK.
This expects a raw json serialized JWK. It works with any Signature scheme.
Sourcepub fn parse_public_key(
key: &[u8],
signature_scheme: SignatureScheme,
) -> Result<ExternalSender>
pub fn parse_public_key( key: &[u8], signature_scheme: SignatureScheme, ) -> Result<ExternalSender>
Parse an external sender given a raw public key.
This supports the legacy behaviour where the server was providing the external sender public key raw.
Sourcepub fn parse(
key: &[u8],
signature_scheme: SignatureScheme,
) -> Result<ExternalSender>
pub fn parse( key: &[u8], signature_scheme: SignatureScheme, ) -> Result<ExternalSender>
Parse an external sender.
This first attempts to parse this as a JWK per parse_jwk,
and falls back to parse_public_key if the former method fails.
Methods from Deref<Target = MlsExternalSender>
pub fn credential(&self) -> &Credential
pub fn signature_key(&self) -> &SignaturePublicKey