pub struct QualifiedClientId(/* private fields */);Expand description
This type wraps ClientId and verifies upon instantiation that it conforms to the <userid>-<device-id>@<domain>
format.
[E2eiClientId] would have been antoher natural canditate to wrap, since it holds the triple data internally. However, this type is intended to be used as a ClientId more often than it is to be used as [E2eiClientId], so it should deref to the former.
Implementations