Session

Struct Session 

pub struct Session { /* private fields */ }
A MLS Session enables a user device to communicate via the MLS protocol.

This closely maps to the Client term in RFC 9720, but we avoid that term to avoid ambiguity; Client is very overloaded with distinct meanings.

There is one Session per user per device. A session can contain many MLS groups/conversations.

It is cheap to clone a Session because everything heavy is wrapped inside an Arc.

Implementations

Source

impl Session

pub async fn e2ei_is_pki_env_setup(&self) -> bool

Returns whether the E2EI PKI environment is setup (i.e. Root CA, Intermediates, CRLs)

pub async fn e2ei_is_enabled( &self, cipher_suite: CipherSuite, ) -> Result<bool, Error>

Returns true if end-to-end-identity is enabled for the given cipher suite.

This is determined by checking for existence of credentials for the given cipher suite: If there are x509 (and optionally basic) credentials -> Ok(true) If there are no x509 but basic credentials -> Ok(false) If there are no credentials for the given cipher suite -> Err(CredentialNotFound)

pub async fn e2ei_verify_group_state( &self, group_info: VerifiableGroupInfo, ) -> Result<E2eiConversationState, Error>

Verifies a Group state before joining it

pub async fn get_credential_in_use( &self, group_info: VerifiableGroupInfo, credential_type: CredentialType, ) -> Result<E2eiConversationState, Error>

Gets the e2ei conversation state from a GroupInfo. Useful to check if the group has e2ei turned on or not before joining it.

Source

impl Session

pub async fn register_epoch_observer( &self, epoch_observer: Arc<dyn EpochObserver>, ) -> Result<(), Error>

Add an epoch observer to this session. (see EpochObserver).

This function should be called 0 or 1 times in a session’s lifetime. If called when an epoch observer already exists, this will return an error.

Source

impl Session

pub async fn register_history_observer( &self, history_observer: Arc<dyn HistoryObserver>, ) -> Result<()>

Add an history observer to this session. (see HistoryObserver).

This function should be called 0 or 1 times in a session’s lifetime. If called when an epoch observer already exists, this will return an error.

Source

impl Session

pub async fn get_keypackage_refs(&self) -> Result<Vec<KeypackageRef>, Error>

Get all KeypackageRefs in the database.

Source

impl Session

pub fn new( id: ClientId, crypto_provider: CryptoProvider, database: ImmutableDatabase, transport: Arc<dyn MlsTransport>, ) -> Self

Create a new Session

pub async fn get_raw_conversation( &self, id: &ConversationIdRef, ) -> Result<Conversation, Error>

Get an immutable view of an MLS conversation.

This may be faster than crate::transaction_context::TransactionContext::conversation.

pub async fn conversation_exists( &self, id: &ConversationIdRef, ) -> Result<bool, Error>

Checks if a given conversation id exists locally

pub fn random_bytes(&self, len: usize) -> Result<Vec<u8>>

Generates a random byte array of the specified size

pub fn database(&self) -> &ImmutableDatabase

Get read-only access to the database.

pub async fn reseed(&self, seed: Option<EntropySeed>) -> Result<()>

pub fn id(&self) -> ClientId

Retrieves the client’s client id. This is free-form and not inspected.