X509Identity

Struct X509Identity 

pub struct X509Identity {
    pub handle: String,
    pub display_name: String,
    pub domain: String,
    pub certificate: String,
    pub serial_number: String,
    pub not_before: u64,
    pub not_after: u64,
}
Represents the parts of WireIdentity that are specific to a X509 certificate (and not a Basic one).

We don’t use an enum here since the sole purpose of this is to be exposed through the FFI (and union types are impossible to carry over the FFI boundary)

Fields

handle: String

user handle e.g. john_wire

display_name: String

Name as displayed in the messaging application e.g. John Fitzgerald Kennedy

domain: String

DNS domain for which this identity proof was generated e.g. whitehouse.gov

certificate: String

X509 certificate identifying this client in the MLS group ; PEM encoded

serial_number: String

X509 certificate serial number

not_before: u64

X509 certificate not before as Unix timestamp

not_after: u64

X509 certificate not after as Unix timestamp