HistoryObserver

Trait HistoryObserver 

pub trait HistoryObserver: Send + Sync {
    // Required method
    fn history_client_created<'life0, 'life1, 'async_trait>(
        &'life0 self,
        conversation_id: ConversationId,
        secret: &'life1 HistorySecret,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
The HistoryObserver will be called when updating the history client in a conversation

Required Methods

fn history_client_created<'life0, 'life1, 'async_trait>( &'life0 self, conversation_id: ConversationId, secret: &'life1 HistorySecret, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

This function will be called when a new history client has been created and accepted by the delivery service.

The secret parameter contains the history client’s secrets.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors