pub enum Error {
Show 14 variants
CallerError(&'static str),
InvalidTransactionContext,
ConversationAlreadyExists(ConversationId),
ConversationNotFound(ConversationId),
PendingConversation(PendingConversation),
ProteusNotInitialized,
PkiEnvironmentUnset,
Keystore(KeystoreError),
OpenMls(OpenMlsError),
CredentialStillInUse(ConversationId),
WrongCredential,
InvalidCredentials(Vec<CredentialRef>),
KeypackageNew(String),
Recursive(RecursiveError),
}Expand description
Errors produced during a transaction
Variants
CallerError(&'static str)
InvalidTransactionContext
ConversationAlreadyExists(ConversationId)
This error is emitted when the requested conversation already exists with the given id
ConversationNotFound(ConversationId)
This error is emitted when the requested conversation couldn’t be found in our store
PendingConversation(PendingConversation)
ProteusNotInitialized
PkiEnvironmentUnset
Keystore(KeystoreError)
OpenMls(OpenMlsError)
CredentialStillInUse(ConversationId)
WrongCredential
InvalidCredentials(Vec<CredentialRef>)
KeypackageNew(String)
Recursive(RecursiveError)
Implementations