Database

Struct Database 

pub struct Database { /* private fields */ }

Implementations

Source

impl Database

pub async fn open( location: ConnectionType<'_>, key: &DatabaseKey, ) -> Result<Database, CryptoKeystoreError>

pub async fn location(&self) -> Result<Option<String>, CryptoKeystoreError>

pub async fn conn(&self) -> Result<ConnectionGuard<'_>, CryptoKeystoreError>

Get direct exclusive access to the connection.

pub async fn close(&self) -> Result<(), CryptoKeystoreError>

pub async fn wipe(&self) -> Result<(), CryptoKeystoreError>

Close this database and delete its contents.

pub async fn export_copy( &self, destination_path: &str, ) -> Result<(), CryptoKeystoreError>

Export a copy of the database to the specified path. This creates a fully vacuumed and optimized copy of the database. The copy will be encrypted with the same key as the source database.

Platform Support

This method is only available on platforms using SQLCipher (not WASM).

Arguments
  • destination_path - The file path where the database copy should be created
Errors

Returns an error if:

  • The database is in-memory (cannot export in-memory databases)
  • The destination path is invalid
  • The export operation fails
pub async fn migrate_db_key_type_to_bytes( name: &str, old_key: &str, new_key: &DatabaseKey, ) -> Result<(), CryptoKeystoreError>

pub async fn update_key( &mut self, new_key: &DatabaseKey, ) -> Result<(), CryptoKeystoreError>

pub async fn new_transaction(&self) -> Result<(), CryptoKeystoreError>

Waits for the current transaction to be committed or rolled back, then starts a new one.

pub async fn commit_transaction(&self) -> Result<(), CryptoKeystoreError>

pub async fn rollback_transaction(&self) -> Result<(), CryptoKeystoreError>

pub async fn child_groups( &self, entity: PersistedMlsGroup, ) -> Result<Vec<PersistedMlsGroup>, CryptoKeystoreError>

pub async fn save<'a, E>( &self, entity: E, ) -> Result<<E as EntityBase>::AutoGeneratedFields, CryptoKeystoreError>

pub async fn remove<'a, E>( &self, id: &<E as PrimaryKey>::PrimaryKey, ) -> Result<(), CryptoKeystoreError>

pub async fn remove_borrowed<'a, E>( &self, id: &<E as BorrowPrimaryKey>::BorrowedPrimaryKey, ) -> Result<(), CryptoKeystoreError>

pub async fn find_pending_messages_by_conversation_id( &self, conversation_id: &[u8], ) -> Result<Vec<MlsPendingMessage>, CryptoKeystoreError>

pub async fn remove_pending_messages_by_conversation_id( &self, conversation_id: impl AsRef<[u8]> + Send, ) -> Result<(), CryptoKeystoreError>